@@ -39,15 +39,15 @@ fn main() -> Result<(), Error> {
         .arg(Arg::with_name("force").short("f").long("force").takes_value(false).help("Force downloading of existing images"))
         .get_matches();
 
-    let url = Url::parse(matches.value_of("url").or(Some("")).unwrap())
-        .or(Url::parse(&format!("https://post.naver.com/viewer/postView.nhn?volumeNo={}", matches.value_of("url").unwrap())))?;
+    let url = Url::parse(matches.value_of("input").or(Some("")).unwrap())
+        .or(Url::parse(&format!("https://post.naver.com/viewer/postView.nhn?volumeNo={}", matches.value_of("input").unwrap())))?;
 
     let id = url.query_pairs().find(|item| item.0.eq("volumeNo"))
         .ok_or_else(|| Error::MissingVolumeNoParamError)?.1;
 
     let volume = Volume::get(id)?;
 
-    let mut dest = match matches.value_of("dir") {
+    let mut dest = match matches.value_of("output") {
         Some(path) => {
             let path = Path::new(path);
             if !path.is_dir() { fs::create_dir_all(path)? }
@@ -79,7 +79,7 @@ fn main() -> Result<(), Error> {
 
         let existing = image::image_dimensions(&path);
 
-        if existing.is_ok() && !matches.is_present("f") {
+        if existing.is_ok() && !matches.is_present("force") {
             images.push((filename, File::open(path)?));
         } else {
             if Path::exists(&path) { fs::remove_file(&path)? };
@@ -97,7 +97,7 @@ fn main() -> Result<(), Error> {
 
     if !matches.is_present("skip-metadata") {
         let path = &dest.join("metadata.txt");
-        if Path::exists(&path) { fs::remove_file(&path)? };
+        if Path::exists(&path) && matches.is_present("force") { fs::remove_file(&path)? };
 
         println!("Writing metadata...");
 
